import type { PaginationConfiguration } from "@smithy/types";
import { BedrockRuntimeClient } from "../BedrockRuntimeClient";
/**
 * @public
 */
export interface BedrockRuntimePaginationConfiguration extends PaginationConfiguration {
    client: BedrockRuntimeClient;
}
