import { PaginationConfiguration } from "@smithy/types";
import { BedrockRuntimeClient } from "../BedrockRuntimeClient";
export interface BedrockRuntimePaginationConfiguration
  extends PaginationConfiguration {
  client: BedrockRuntimeClient;
}
