import { TypeRegistry } from "@smithy/core/schema";
import type { StaticErrorSchema, StaticOperationSchema, StaticStructureSchema, StaticUnionSchema } from "@smithy/types";
export declare var BedrockRuntimeServiceException$: StaticErrorSchema;
export declare var AccessDeniedException$: StaticErrorSchema;
export declare var ConflictException$: StaticErrorSchema;
export declare var InternalServerException$: StaticErrorSchema;
export declare var ModelErrorException$: StaticErrorSchema;
export declare var ModelNotReadyException$: StaticErrorSchema;
export declare var ModelStreamErrorException$: StaticErrorSchema;
export declare var ModelTimeoutException$: StaticErrorSchema;
export declare var ResourceNotFoundException$: StaticErrorSchema;
export declare var ServiceQuotaExceededException$: StaticErrorSchema;
export declare var ServiceUnavailableException$: StaticErrorSchema;
export declare var ThrottlingException$: StaticErrorSchema;
export declare var ValidationException$: StaticErrorSchema;
/**
 * TypeRegistry instances containing modeled errors.
 * @internal
 *
 */
export declare const errorTypeRegistries: TypeRegistry[];
export declare var AnyToolChoice$: StaticStructureSchema;
export declare var AppliedGuardrailDetails$: StaticStructureSchema;
export declare var ApplyGuardrailRequest$: StaticStructureSchema;
export declare var ApplyGuardrailResponse$: StaticStructureSchema;
export declare var AsyncInvokeS3OutputDataConfig$: StaticStructureSchema;
export declare var AsyncInvokeSummary$: StaticStructureSchema;
export declare var AudioBlock$: StaticStructureSchema;
export declare var AutoToolChoice$: StaticStructureSchema;
export declare var BidirectionalInputPayloadPart$: StaticStructureSchema;
export declare var BidirectionalOutputPayloadPart$: StaticStructureSchema;
export declare var CacheDetail$: StaticStructureSchema;
export declare var CachePointBlock$: StaticStructureSchema;
export declare var Citation$: StaticStructureSchema;
export declare var CitationsConfig$: StaticStructureSchema;
export declare var CitationsContentBlock$: StaticStructureSchema;
export declare var CitationsDelta$: StaticStructureSchema;
export declare var CitationSourceContentDelta$: StaticStructureSchema;
export declare var ContentBlockDeltaEvent$: StaticStructureSchema;
export declare var ContentBlockStartEvent$: StaticStructureSchema;
export declare var ContentBlockStopEvent$: StaticStructureSchema;
export declare var ConverseMetrics$: StaticStructureSchema;
export declare var ConverseRequest$: StaticStructureSchema;
export declare var ConverseResponse$: StaticStructureSchema;
export declare var ConverseStreamMetadataEvent$: StaticStructureSchema;
export declare var ConverseStreamMetrics$: StaticStructureSchema;
export declare var ConverseStreamRequest$: StaticStructureSchema;
export declare var ConverseStreamResponse$: StaticStructureSchema;
export declare var ConverseStreamTrace$: StaticStructureSchema;
export declare var ConverseTokensRequest$: StaticStructureSchema;
export declare var ConverseTrace$: StaticStructureSchema;
export declare var CountTokensRequest$: StaticStructureSchema;
export declare var CountTokensResponse$: StaticStructureSchema;
export declare var DocumentBlock$: StaticStructureSchema;
export declare var DocumentCharLocation$: StaticStructureSchema;
export declare var DocumentChunkLocation$: StaticStructureSchema;
export declare var DocumentPageLocation$: StaticStructureSchema;
export declare var ErrorBlock$: StaticStructureSchema;
export declare var GetAsyncInvokeRequest$: StaticStructureSchema;
export declare var GetAsyncInvokeResponse$: StaticStructureSchema;
export declare var GuardrailAssessment$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningImpossibleFinding$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningInputTextReference$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningInvalidFinding$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningLogicWarning$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningNoTranslationsFinding$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningPolicyAssessment$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningRule$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningSatisfiableFinding$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningScenario$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningStatement$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningTooComplexFinding$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningTranslation$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningTranslationAmbiguousFinding$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningTranslationOption$: StaticStructureSchema;
export declare var GuardrailAutomatedReasoningValidFinding$: StaticStructureSchema;
export declare var GuardrailConfiguration$: StaticStructureSchema;
export declare var GuardrailContentFilter$: StaticStructureSchema;
export declare var GuardrailContentPolicyAssessment$: StaticStructureSchema;
export declare var GuardrailContextualGroundingFilter$: StaticStructureSchema;
export declare var GuardrailContextualGroundingPolicyAssessment$: StaticStructureSchema;
export declare var GuardrailConverseImageBlock$: StaticStructureSchema;
export declare var GuardrailConverseTextBlock$: StaticStructureSchema;
export declare var GuardrailCoverage$: StaticStructureSchema;
export declare var GuardrailCustomWord$: StaticStructureSchema;
export declare var GuardrailImageBlock$: StaticStructureSchema;
export declare var GuardrailImageCoverage$: StaticStructureSchema;
export declare var GuardrailInvocationMetrics$: StaticStructureSchema;
export declare var GuardrailManagedWord$: StaticStructureSchema;
export declare var GuardrailOutputContent$: StaticStructureSchema;
export declare var GuardrailPiiEntityFilter$: StaticStructureSchema;
export declare var GuardrailRegexFilter$: StaticStructureSchema;
export declare var GuardrailSensitiveInformationPolicyAssessment$: StaticStructureSchema;
export declare var GuardrailStreamConfiguration$: StaticStructureSchema;
export declare var GuardrailTextBlock$: StaticStructureSchema;
export declare var GuardrailTextCharactersCoverage$: StaticStructureSchema;
export declare var GuardrailTopic$: StaticStructureSchema;
export declare var GuardrailTopicPolicyAssessment$: StaticStructureSchema;
export declare var GuardrailTraceAssessment$: StaticStructureSchema;
export declare var GuardrailUsage$: StaticStructureSchema;
export declare var GuardrailWordPolicyAssessment$: StaticStructureSchema;
export declare var ImageBlock$: StaticStructureSchema;
export declare var ImageBlockDelta$: StaticStructureSchema;
export declare var ImageBlockStart$: StaticStructureSchema;
export declare var InferenceConfiguration$: StaticStructureSchema;
export declare var InvokeModelRequest$: StaticStructureSchema;
export declare var InvokeModelResponse$: StaticStructureSchema;
export declare var InvokeModelTokensRequest$: StaticStructureSchema;
export declare var InvokeModelWithBidirectionalStreamRequest$: StaticStructureSchema;
export declare var InvokeModelWithBidirectionalStreamResponse$: StaticStructureSchema;
export declare var InvokeModelWithResponseStreamRequest$: StaticStructureSchema;
export declare var InvokeModelWithResponseStreamResponse$: StaticStructureSchema;
export declare var JsonSchemaDefinition$: StaticStructureSchema;
export declare var ListAsyncInvokesRequest$: StaticStructureSchema;
export declare var ListAsyncInvokesResponse$: StaticStructureSchema;
export declare var Message$: StaticStructureSchema;
export declare var MessageStartEvent$: StaticStructureSchema;
export declare var MessageStopEvent$: StaticStructureSchema;
export declare var OutputConfig$: StaticStructureSchema;
export declare var OutputFormat$: StaticStructureSchema;
export declare var PayloadPart$: StaticStructureSchema;
export declare var PerformanceConfiguration$: StaticStructureSchema;
export declare var PromptRouterTrace$: StaticStructureSchema;
export declare var ReasoningTextBlock$: StaticStructureSchema;
export declare var S3Location$: StaticStructureSchema;
export declare var SearchResultBlock$: StaticStructureSchema;
export declare var SearchResultContentBlock$: StaticStructureSchema;
export declare var SearchResultLocation$: StaticStructureSchema;
export declare var ServiceTier$: StaticStructureSchema;
export declare var SpecificToolChoice$: StaticStructureSchema;
export declare var StartAsyncInvokeRequest$: StaticStructureSchema;
export declare var StartAsyncInvokeResponse$: StaticStructureSchema;
export declare var SystemTool$: StaticStructureSchema;
export declare var Tag$: StaticStructureSchema;
export declare var TokenUsage$: StaticStructureSchema;
export declare var ToolConfiguration$: StaticStructureSchema;
export declare var ToolResultBlock$: StaticStructureSchema;
export declare var ToolResultBlockStart$: StaticStructureSchema;
export declare var ToolSpecification$: StaticStructureSchema;
export declare var ToolUseBlock$: StaticStructureSchema;
export declare var ToolUseBlockDelta$: StaticStructureSchema;
export declare var ToolUseBlockStart$: StaticStructureSchema;
export declare var VideoBlock$: StaticStructureSchema;
export declare var WebLocation$: StaticStructureSchema;
export declare var AsyncInvokeOutputDataConfig$: StaticUnionSchema;
export declare var AudioSource$: StaticUnionSchema;
export declare var CitationGeneratedContent$: StaticUnionSchema;
export declare var CitationLocation$: StaticUnionSchema;
export declare var CitationSourceContent$: StaticUnionSchema;
export declare var ContentBlock$: StaticUnionSchema;
export declare var ContentBlockDelta$: StaticUnionSchema;
export declare var ContentBlockStart$: StaticUnionSchema;
export declare var ConverseOutput$: StaticUnionSchema;
export declare var ConverseStreamOutput$: StaticUnionSchema;
export declare var CountTokensInput$: StaticUnionSchema;
export declare var DocumentContentBlock$: StaticUnionSchema;
export declare var DocumentSource$: StaticUnionSchema;
export declare var GuardrailAutomatedReasoningFinding$: StaticUnionSchema;
export declare var GuardrailContentBlock$: StaticUnionSchema;
export declare var GuardrailConverseContentBlock$: StaticUnionSchema;
export declare var GuardrailConverseImageSource$: StaticUnionSchema;
export declare var GuardrailImageSource$: StaticUnionSchema;
export declare var ImageSource$: StaticUnionSchema;
export declare var InvokeModelWithBidirectionalStreamInput$: StaticUnionSchema;
export declare var InvokeModelWithBidirectionalStreamOutput$: StaticUnionSchema;
export declare var OutputFormatStructure$: StaticUnionSchema;
export declare var PromptVariableValues$: StaticUnionSchema;
export declare var ReasoningContentBlock$: StaticUnionSchema;
export declare var ReasoningContentBlockDelta$: StaticUnionSchema;
export declare var ResponseStream$: StaticUnionSchema;
export declare var SystemContentBlock$: StaticUnionSchema;
export declare var Tool$: StaticUnionSchema;
export declare var ToolChoice$: StaticUnionSchema;
export declare var ToolInputSchema$: StaticUnionSchema;
export declare var ToolResultBlockDelta$: StaticUnionSchema;
export declare var ToolResultContentBlock$: StaticUnionSchema;
export declare var VideoSource$: StaticUnionSchema;
export declare var ApplyGuardrail$: StaticOperationSchema;
export declare var Converse$: StaticOperationSchema;
export declare var ConverseStream$: StaticOperationSchema;
export declare var CountTokens$: StaticOperationSchema;
export declare var GetAsyncInvoke$: StaticOperationSchema;
export declare var InvokeModel$: StaticOperationSchema;
export declare var InvokeModelWithBidirectionalStream$: StaticOperationSchema;
export declare var InvokeModelWithResponseStream$: StaticOperationSchema;
export declare var ListAsyncInvokes$: StaticOperationSchema;
export declare var StartAsyncInvoke$: StaticOperationSchema;
