import type { Paginator } from "@smithy/types";
import { ListAsyncInvokesCommandInput, ListAsyncInvokesCommandOutput } from "../commands/ListAsyncInvokesCommand";
import { BedrockRuntimePaginationConfiguration } from "./Interfaces";
/**
 * @public
 */
export declare const paginateListAsyncInvokes: (config: BedrockRuntimePaginationConfiguration, input: ListAsyncInvokesCommandInput, ...rest: any[]) => Paginator<ListAsyncInvokesCommandOutput>;
